@@ -1,32 +1,11 @@
 from datetime import datetime
-from typing import Type
+from typing import Optional
 
 import sqlalchemy
 from sqlalchemy.ext import declarative
 
 
-class _Base:
-    def __init_subclass__(cls, created_at=False, updated_at=False, **kwargs):
-        super().__init_subclass__(**kwargs)
-
-        if created_at:
-            cls.created_at = sqlalchemy.Column(
-                sqlalchemy.types.DateTime(timezone=True),
-                default=datetime.utcnow,
-                server_default=sqlalchemy.text("CURRENT_TIMESTAMP"),
-                nullable=False,
-            )
-
-        if updated_at:
-            cls.updated_at = sqlalchemy.Column(
-                sqlalchemy.types.DateTime(timezone=True),
-                onupdate=datetime.utcnow,
-                nullable=True,
-                **kwargs,
-            )
-
-
-def declarative_base(base=None, *, repr=True) -> Type[_Base]:
+def declarative_base(base: Optional[declarative.DeclarativeMeta] = None, *, repr=True):
     """Define a declarative base class.
 
     Args:
@@ -48,7 +27,32 @@ def declarative_base(base=None, *, repr=True) -> Type[_Base]:
     if base is None:
         base = declarative.declarative_base(metaclass=_DeclarativeMeta)
 
-    return type("Base", (base, _Base), {"__abstract__": True, "__repr__": repr_fn})
+    class Base(base):
+        __abstract__ = True
+
+        if repr:
+            __repr__ = repr_fn
+
+        def __init_subclass__(cls, created_at=False, updated_at=False, **kwargs):
+            super().__init_subclass__(**kwargs)
+
+            if created_at:
+                cls.created_at = sqlalchemy.Column(
+                    sqlalchemy.types.DateTime(timezone=True),
+                    default=datetime.utcnow,
+                    server_default=sqlalchemy.text("CURRENT_TIMESTAMP"),
+                    nullable=False,
+                )
+
+            if updated_at:
+                cls.updated_at = sqlalchemy.Column(
+                    sqlalchemy.types.DateTime(timezone=True),
+                    onupdate=datetime.utcnow,
+                    nullable=True,
+                    **kwargs,
+                )
+
+    return Base
 
 
 def repr_fn(instance):
